require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module DigitalWorkspace
    module DigitalWorkspace
      class DigitalWorkspaceRecordAttributes < UU::OS::REST::DTO

        #Name of the digital workspace record. It's the same name as the name of activity that the record represents.
        attr_accessor :name
        #Description of the digital workspace record. It's the same description as the description of activity that the record represents.
        attr_accessor :description
        #Specifies the date when the activity is shown in the roles digital workspace.
        attr_accessor :date_from
        #The date when the executive role should perform the activity. In case of task type activities is date_start same as date_from.
        #It represents the start of meeting in case of activity of type TIME_RESERVATION or COVER_MEETING. For other activity types
        #the date_start is the same as date_from.
        attr_accessor :date_start
        #The date when the activity should be finished.
        attr_accessor :date_to
        #The date when the activity is automatically finished. The date is always after the date_to attribute.
        attr_accessor :date_expiration
        #The date when the activity was finished.
        attr_accessor :date_completed
        #UES URI of the activity which is represented by digital workspace record. UESURI is in the canonical form (without codes).
        attr_accessor :activity_uri
        #Specifies the type of the activity which is represented by digital workspace record.
        # @see UU::OS::Activity::ActivityType
        attr_accessor :activity_type
        #Name of the state of activity which is represented by digital workspace record.
        attr_accessor :activity_state_name
        #Comment of the current state of activity which is represented by digital workspace record.
        attr_accessor :activity_state_description
        #Type of the current state of activity which is represented by digital workspace record.
        # @see UU::OS::Activity::ActivityStateType
        attr_accessor :activity_state_type
        #Subtype of the current state of activity which is represented by digital workspace record.
        # @see UU::OS::Activity::ActivityStateSubtype
        attr_accessor :activity_state_subtype
        #UES URI of the competent role of the activity (submitter of the activity) which is represented by digital workspace record. UESURI is in the canonical form (without codes).
        attr_accessor :competent_role_uri
        #Name of the state of the competent role of the activity (submitter of the activity) which is represented by digital workspace record.
        attr_accessor :competent_role_name
        #UES URI of the state of the executive role of the activity (solver of the activity) which is represented by digital workspace record. UESURI is in the canonical form (without codes).
        attr_accessor :executive_role_uri
        #Name of the state of the executive role of the activity (solver of the activity) which is represented by digital workspace record.
        attr_accessor :executive_role_name
        #UES URI of the artifact of the activity which is represented by digital workspace record. UESURI is in the normalized form (with codes).
        attr_accessor :artifact_uri
        #Name of the artifact of the activity which is represented by digital workspace record.
        attr_accessor :artifact_name
        #UES URI of the related object of the activity which is represented by digital workspace record. UESURI is in the normalized form (with codes).
        attr_accessor :related_object_uri
        #Name of the related object of the activity which is represented by digital workspace record.
        attr_accessor :related_object_name
        #Specifies whether the record is new to the Personal Role's Digital Workspace. A new record is always marked as unread.
        #The record remains new until the user first interacts with the record or the corresponding activity (shows the activity detail,
        #sets the activity state, marks the record as read, etc.). Once the record is not new, it cannot be marked as new again.
        #Note: If the main entity is a Role, then the record is always marked as new (true). Never nil.
        attr_accessor :is_new
        #Specifies whether the record is unread in the Personal Role's Digital Workspace. The record remains unread until the user
        #interacts with the record or the corresponding activity (shows the activity detail, sets the activity state, marks the record
        #as read, etc.). A record that is marked as read can be marked as unread again (manually by the user, or when the activity state is
        #changed by another user, etc.). Note: If the main entity is a Role, the record is always marked as unread (true). Never nil.
        attr_accessor :is_unread
        #UESURI of the DW Record. Never nil. UESURI is in the normalized form (with codes).
        attr_accessor :uri
        #UESURI of the Personal Role for which the DW Record is listed. Never nil. UESURI is in the normalized form (with codes).
        attr_accessor :parent_uri
        #Direction of the activity regarding the role for which the DW Record is listed. The activity can be incoming (IN), outgoing (OUT) or own (OWN). Never nil.
        # @see UU::DigitalWorkspace::DigitalWorkspaceRecordDirection
        attr_accessor :direction
        #Specifies whether the activity is waiting for the reaction of the other party (competent or executive role). Always false if the activity is completed. Never nil.
        attr_accessor :pending
        #Specifies whether the activity of type TIME_RESERVATION or COVER_MEETING blocks time in the calendar. Nil for activities of other types, see UU::OS::Activity::ActivityType.
        attr_accessor :block_time_in_calendar
        
        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def date_from
          attributes[:dateFrom]
        end

        def date_from=(val)
          attributes[:dateFrom] = val
        end

        def date_start
          attributes[:dateStart]
        end

        def date_start=(val)
          attributes[:dateStart] = val
        end

        def date_to
          attributes[:dateTo]
        end

        def date_to=(val)
          attributes[:dateTo] = val
        end

        def date_expiration
          attributes[:dateExpiration]
        end

        def date_expiration=(val)
          attributes[:dateExpiration] = val
        end

        def date_completed
          attributes[:dateCompleted]
        end

        def date_completed=(val)
          attributes[:dateCompleted] = val
        end

        def activity_uri
          attributes[:activityUri]
        end

        def activity_uri=(val)
          if val
            attributes[:activityUri] = UU::OS::UESURI.new(val)
          else
            attributes[:activityUri] = nil
          end
        end

        def activity_type
          attributes[:activityType]
        end

        def activity_type=(val)
          attributes[:activityType] = val
        end

        def activity_state_name
          attributes[:activityStateName]
        end

        def activity_state_name=(val)
          attributes[:activityStateName] = val
        end

        def activity_state_description
          attributes[:activityStateDescription]
        end

        def activity_state_description=(val)
          attributes[:activityStateDescription] = val
        end

        def activity_state_type
          attributes[:activityStateType]
        end

        def activity_state_type=(val)
          attributes[:activityStateType] = val
        end

        def activity_state_subtype
          attributes[:activityStateSubtype]
        end

        def activity_state_subtype=(val)
          attributes[:activityStateSubtype] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def competent_role_name
          attributes[:competentRoleName]
        end

        def competent_role_name=(val)
          attributes[:competentRoleName] = val
        end

        def executive_role_uri
          attributes[:executiveRoleUri]
        end

        def executive_role_uri=(val)
          if val
            attributes[:executiveRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:executiveRoleUri] = nil
          end
        end

        def executive_role_name
          attributes[:executiveRoleName]
        end

        def executive_role_name=(val)
          attributes[:executiveRoleName] = val
        end

        def artifact_uri
          attributes[:artifactUri]
        end

        def artifact_uri=(val)
          if val
            attributes[:artifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:artifactUri] = nil
          end
        end

        def artifact_name
          attributes[:artifactName]
        end

        def artifact_name=(val)
          attributes[:artifactName] = val
        end

        def related_object_uri
          attributes[:relatedObjectUri]
        end

        def related_object_uri=(val)
          if val
            attributes[:relatedObjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:relatedObjectUri] = nil
          end
        end

        def related_object_name
          attributes[:relatedObjectName]
        end

        def related_object_name=(val)
          attributes[:relatedObjectName] = val
        end

        def is_new
          attributes[:isNew]
        end

        def is_new=(val)
          attributes[:isNew] = val
        end

        def is_unread
          attributes[:isUnread]
        end

        def is_unread=(val)
          attributes[:isUnread] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          attributes[:uri] = val
        end
        
        def parent_uri
          attributes[:parentUri]
        end

        def parent_uri=(val)
          attributes[:parentUri] = val
        end
        
        def direction
          attributes[:direction]
        end

        def direction=(val)
          attributes[:direction] = val
        end
        
        def pending
          attributes[:pending]
        end

        def pending=(val)
          attributes[:pending] = val
        end
        
        def block_time_in_calendar
          attributes[:blockTimeInCalendar]
        end

        def block_time_in_calendar=(val)
          attributes[:blockTimeInCalendar] = val
        end
      end
    end
  end
end